@@ -14,7 +14,10 @@ import pprint
 
 from itertools import count
 
-from amqplib import client_0_8 as amqp
+try:
+    import amqp
+except ImportError:
+    from amqplib import client_0_8 as amqp  # noqa
 
 from celery.app import app_or_default
 from celery.utils.functional import padlist
@@ -89,8 +92,8 @@ class Spec(object):
             ('pobox', True)
 
         """
-        return tuple(self.coerce(index, value)
-                for index, value in enumerate(arglist))
+        return tuple(
+            self.coerce(index, value) for index, value in enumerate(arglist))
 
     def format_response(self, response):
         """Format the return value of this command in a human-friendly way."""
@@ -109,7 +112,7 @@ class Spec(object):
 
     def format_signature(self):
         return ' '.join(self.format_arg(*padlist(list(arg), 3))
-                            for arg in self.args)
+                        for arg in self.args)
 
 
 def dump_message(message):
@@ -216,7 +219,7 @@ class AMQShell(cmd.Cmd):
 
             >>> get_amqp_api_command('queue.delete', ['pobox', 'yes', 'no'])
             (<bound method Channel.queue_delete of
-             <amqplib.client_0_8.channel.Channel object at 0x...>>,
+             <amqp.channel.Channel object at 0x...>>,
              ('testfoo', True, False))
 
         """
@@ -239,7 +242,7 @@ class AMQShell(cmd.Cmd):
     def do_help(self, *args):
         if not args:
             self.say(HELP_HEADER)
-            for cmd_name in self.amqp.keys():
+            for cmd_name in self.amqp:
                 self.display_command_help(cmd_name, short=True)
             self.say(EXAMPLE_TEXT)
         else:
@@ -255,11 +258,11 @@ class AMQShell(cmd.Cmd):
         """Return all commands starting with `text`, for tab-completion."""
         names = self.get_names()
         first = [cmd for cmd in names
-                        if cmd.startswith(text.replace('_', '.'))]
+                 if cmd.startswith(text.replace('_', '.'))]
         if first:
             return first
         return [cmd for cmd in names
-                    if cmd.partition('.')[2].startswith(text)]
+                if cmd.partition('.')[2].startswith(text)]
 
     def dispatch(self, cmd, argline):
         """Dispatch and execute the command.
