@@ -3,29 +3,7 @@
 celery.contrib.batches
 ======================
 
-Collect messages and processes them as a list.
-
-**Example**
-
-A click counter that flushes the buffer every 100 messages, and every
-10 seconds.
-
-.. code-block:: python
-
-    from celery import task
-    from celery.contrib.batches import Batches
-
-    # Flush after 100 messages, or 10 seconds.
-    @task(base=Batches, flush_every=100, flush_interval=10)
-    def count_click(requests):
-        from collections import Counter
-        count = Counter(request.kwargs['url'] for request in requests)
-        for url, count in count.items():
-            print('>>> Clicks: %s -> %s' % (url, count))
-
-Registering the click is done as follows:
-
-    >>> count_click.delay(url='http://example.com')
+Experimental task class that buffers messages and processes them as a list.
 
 .. warning::
 
@@ -36,6 +14,72 @@ Registering the click is done as follows:
     In the future we hope to add the ability to direct batching tasks
     to a channel with different QoS requirements than the task channel.
 
+**Simple Example**
+
+A click counter that flushes the buffer every 100 messages, and every
+seconds.  Does not do anything with the data, but can easily be modified
+to store it in a database.
+
+.. code-block:: python
+
+    # Flush after 100 messages, or 10 seconds.
+    @app.task(base=Batches, flush_every=100, flush_interval=10)
+    def count_click(requests):
+        from collections import Counter
+        count = Counter(request.kwargs['url'] for request in requests)
+        for url, count in count.items():
+            print('>>> Clicks: %s -> %s' % (url, count))
+
+
+Then you can ask for a click to be counted by doing::
+
+    >>> count_click.delay('http://example.com')
+
+**Example returning results**
+
+An interface to the Web of Trust API that flushes the buffer every 100
+messages, and every 10 seconds.
+
+.. code-block:: python
+
+    import requests
+    from urlparse import urlparse
+
+    from celery.contrib.batches import Batches
+
+    wot_api_target = "https://api.mywot.com/0.4/public_link_json"
+
+    @app.task(base=Batches, flush_every=100, flush_interval=10)
+    def wot_api(requests):
+        sig = lambda url: url
+        reponses = wot_api_real(
+            (sig(*request.args, **request.kwargs) for request in requests)
+        )
+        # use mark_as_done to manually return response data
+        for response, request in zip(reponses, requests):
+            app.backend.mark_as_done(request.id, response)
+
+
+    def wot_api_real(urls):
+        domains = [urlparse(url).netloc for url in urls]
+        response = requests.get(
+            wot_api_target,
+            params={"hosts": ('/').join(set(domains)) + '/'}
+        )
+        return [response.json[domain] for domain in domains]
+
+Using the API is done as follows::
+
+    >>> wot_api.delay('http://example.com')
+
+.. note::
+
+    If you don't have an ``app`` instance then use the current app proxy
+    instead::
+
+        from celery import current_app
+        app.backend.mark_as_done(request.id, response)
+
 """
 from __future__ import absolute_import
 
@@ -45,7 +89,7 @@ from Queue import Empty, Queue
 from celery.task import Task
 from celery.utils.log import get_logger
 from celery.worker.job import Request
-
+from celery.utils import noop
 
 logger = get_logger(__name__)
 
@@ -167,7 +211,7 @@ class Batches(Task):
 
     def flush(self, requests):
         return self.apply_buffer(requests, ([SimpleRequest.from_request(r)
-                                                for r in requests], ))
+                                             for r in requests], ))
 
     def _do_flush(self):
         logger.debug('Batches: Wake-up to flush buffer...')
@@ -193,7 +237,9 @@ class Batches(Task):
         def on_return(result):
             [req.acknowledge() for req in acks_late[True]]
 
-        return self._pool.apply_async(apply_batches_task,
-                    (self, args, 0, None),
-                    accept_callback=on_accepted,
-                    callback=acks_late[True] and on_return or None)
+        return self._pool.apply_async(
+            apply_batches_task,
+            (self, args, 0, None),
+            accept_callback=on_accepted,
+            callback=acks_late[True] and on_return or noop,
+        )
