@@ -2,16 +2,15 @@ from __future__ import absolute_import
 
 import time
 
-from celery.task import task
-from celery.task.sets import subtask
+from celery import task, subtask
 
 
-@task
+@task()
 def add(x, y):
     return x + y
 
 
-@task
+@task()
 def add_cb(x, y, callback=None):
     result = x + y
     if callback:
@@ -19,7 +18,7 @@ def add_cb(x, y, callback=None):
     return result
 
 
-@task
+@task()
 def sleeptask(i):
     time.sleep(i)
     return i
