@@ -53,8 +53,10 @@ class test_ignore_errno(Case):
 class test_shellsplit(Case):
 
     def test_split(self):
-        self.assertEqual(shellsplit("the 'quick' brown fox"),
-                ['the', 'quick', 'brown', 'fox'])
+        self.assertEqual(
+            shellsplit("the 'quick' brown fox"),
+            ['the', 'quick', 'brown', 'fox'],
+        )
 
 
 class test_set_process_title(Case):
@@ -128,7 +130,7 @@ if not current_app.IS_WINDOWS:
         @patch('celery.platforms.setuid')
         @patch('celery.platforms.initgroups')
         def test_with_uid(self, initgroups, setuid, setgid,
-                getpwuid, parse_uid):
+                          getpwuid, parse_uid):
 
             class pw_struct(object):
                 pw_gid = 50001
@@ -147,7 +149,7 @@ if not current_app.IS_WINDOWS:
         @patch('celery.platforms.setuid')
         @patch('celery.platforms.initgroups')
         def test_with_guid(self, initgroups, setuid, setgid,
-                parse_gid, parse_uid):
+                           parse_gid, parse_uid):
             parse_uid.return_value = 5001
             parse_gid.return_value = 50001
             maybe_drop_privileges(uid='user', gid='group')
@@ -273,7 +275,7 @@ if not current_app.IS_WINDOWS:
         @patch('os.geteuid')
         @patch('__builtin__.open')
         def test_default(self, open, geteuid, maybe_drop,
-                signals, pidlock):
+                         signals, pidlock):
             geteuid.return_value = 0
             context = detached(uid='user', gid='group')
             self.assertIsInstance(context, DaemonContext)
@@ -305,8 +307,8 @@ if not current_app.IS_WINDOWS:
         @patch('os.close')
         @patch('os.open')
         @patch('os.dup2')
-        def test_open(self, dup2, open, close, umask, chdir, _exit, setsid,
-                fork):
+        def test_open(self, dup2, open, close, umask,
+                      chdir, _exit, setsid, fork):
             x = DaemonContext(workdir='/opt/workdir')
 
             fork.return_value = 0
@@ -529,7 +531,7 @@ if not current_app.IS_WINDOWS:
         @patch('os.fdopen')
         @patch('__builtin__.open')
         def test_write_reread_fails(self, open_, fdopen,
-                osopen, getpid, fsync):
+                                    osopen, getpid, fsync):
             getpid.return_value = 1816
             osopen.return_value = 13
             w = fdopen.return_value = WhateverIO()
