@@ -3,23 +3,18 @@
 from __future__ import absolute_import
 
 import weakref
-try:
-    set
-except NameError:
-    from sets import Set as set                 # Python 2.3 fallback
-
 from . import saferef
 
 WEAKREF_TYPES = (weakref.ReferenceType, saferef.BoundMethodWeakref)
 
 
-def _make_id(target):
+def _make_id(target):  # pragma: no cover
     if hasattr(target, 'im_func'):
         return (id(target.im_self), id(target.im_func))
     return id(target)
 
 
-class Signal(object):
+class Signal(object):  # pragma: no cover
     """Base class for all signals
 
 
@@ -82,8 +77,9 @@ class Signal(object):
                     lookup_key = (_make_id(receiver), _make_id(sender))
 
                 if weak:
-                    receiver = saferef.safe_ref(receiver,
-                                            on_delete=self._remove_receiver)
+                    receiver = saferef.safe_ref(
+                        receiver, on_delete=self._remove_receiver,
+                    )
 
                 for r_key, _ in self.receivers:
                     if r_key == lookup_key:
@@ -100,7 +96,7 @@ class Signal(object):
         return _handle_options(*args, **kwargs)
 
     def disconnect(self, receiver=None, sender=None, weak=True,
-            dispatch_uid=None):
+                   dispatch_uid=None):
         """Disconnect receiver from sender for signal.
 
         If weak references are used, disconnect need not be called. The
