@@ -16,10 +16,7 @@ import sys
 
 from contextlib import contextmanager
 
-# symbol_by_name was moved to local because it's used
-# early in the import stage, where celery.utils loads
-# too much (e.g. for eventlet patching)
-from celery.local import symbol_by_name
+from kombu.utils import symbol_by_name
 
 from .compat import reload
 
@@ -31,15 +28,18 @@ class NotAPackage(Exception):
 if sys.version_info >= (3, 3):  # pragma: no cover
 
     def qualname(obj):
-        return obj.__qualname__
-
+        if not hasattr(obj, '__name__') and hasattr(obj, '__class__'):
+            obj = obj.__class__
+        q = getattr(obj, '__qualname__', None)
+        if '.' not in q:
+            q = '.'.join((obj.__module__, q))
+        return q
 else:
 
     def qualname(obj):  # noqa
         if not hasattr(obj, '__name__') and hasattr(obj, '__class__'):
             return qualname(obj.__class__)
-
-        return '%s.%s' % (obj.__module__, obj.__name__)
+        return '.'.join((obj.__module__, obj.__name__))
 
 
 def instantiate(name, *args, **kwargs):
