@@ -107,7 +107,7 @@ class Pool(bootsteps.StartStopComponent):
         add_reader = hub.add_reader
         remove = hub.remove
         now = time.time
-        cache = pool._pool._cache
+        cache = getattr(pool._pool, '_cache', None)
 
         # did_start_ok will verify that pool processes were able to start,
         # but this will only work the first time we start, as
@@ -186,7 +186,7 @@ class Pool(bootsteps.StartStopComponent):
     def create(self, w, semaphore=None, max_restarts=None):
         threaded = not w.use_eventloop
         procs = w.min_concurrency
-        forking_enable = w.no_execv or not w.force_execv
+        forking_enable = w.no_execv if w.force_execv else True
         if not threaded:
             semaphore = w.semaphore = BoundedSemaphore(procs)
             w._quick_acquire = w.semaphore.acquire
