@@ -18,6 +18,7 @@ import shelve
 
 from collections import defaultdict
 
+from kombu.serialization import pickle_protocol
 from kombu.utils import cached_property
 
 from celery import __version__
@@ -130,6 +131,7 @@ class Persistent(object):
 
     """
     storage = shelve
+    protocol = pickle_protocol
     _is_open = False
 
     def __init__(self, filename):
@@ -142,17 +144,24 @@ class Persistent(object):
         self.close()
 
     def merge(self, d):
-        revoked.update(d.get('revoked') or {})
+        saved = d.get('revoked') or LimitedSet()
+        if isinstance(saved, LimitedSet):
+            revoked.update(saved)
+        else:
+            # (pre 3.0.18) used to be stored as dict
+            for item in saved:
+                revoked.add(item)
         return d
 
     def sync(self, d):
-        prev = d.get('revoked') or {}
-        prev.update(revoked.as_dict())
-        d['revoked'] = prev
+        revoked.purge()
+        d['revoked'] = revoked
         return d
 
     def open(self):
-        return self.storage.open(self.filename, writeback=True)
+        return self.storage.open(
+            self.filename, protocol=self.protocol, writeback=True,
+        )
 
     def close(self):
         if self._is_open:
