@@ -9,5 +9,5 @@ except ImportError:
          containing %r." % __file__)
     sys.exit(1)
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     execute_manager(settings)
