@@ -2,7 +2,8 @@ from __future__ import absolute_import
 
 from celery import Celery
 
-celery = Celery(broker='amqp://',
+celery = Celery('proj.celery',
+                broker='amqp://',
                 backend='amqp://',
                 include=['proj.tasks'])
 
@@ -10,3 +11,6 @@ celery = Celery(broker='amqp://',
 celery.conf.update(
     CELERY_TASK_RESULT_EXPIRES=3600,
 )
+
+if __name__ == '__main__':
+    celery.start()
